@@ -9,7 +9,7 @@ esac
 
 if [ -n "$SUFFIX" ]; then
 	OXKER_GZ="oxker_linux_${SUFFIX}.tar.gz"
-	wget "https://github.com/mrjackwills/oxker/releases/latest/download/${OXKER_GZ}"
+	curl -L -O "https://github.com/mrjackwills/oxker/releases/latest/download/${OXKER_GZ}"
 	tar xzvf "${OXKER_GZ}" oxker
 	install -Dm 755 oxker -t "${HOME}/.local/bin"
 	rm "${OXKER_GZ}" oxker
