@@ -30,10 +30,18 @@ impl From<&str> for ContainerId {
 }
 
 impl ContainerId {
+    // TODO remove this once zigbuild uses Rust v1.87.0
+    #[cfg(target_os = "macos")]
+    #[allow(clippy::missing_const_for_fn)]
     pub fn get(&self) -> &str {
         self.0.as_str()
     }
 
+    #[cfg(not(target_os = "macos"))]
+    pub const fn get(&self) -> &str {
+        self.0.as_str()
+    }
+
     /// Only return first 8 chars of id, is usually more than enough for uniqueness
     /// need to update tests to use real ids, or atleast strings of the correct-ish length
     pub fn get_short(&self) -> String {
@@ -76,10 +84,18 @@ macro_rules! unit_struct {
         }
 
         impl $name {
+            #[cfg(target_os = "macos")]
+            #[allow(clippy::missing_const_for_fn)]
+            // TODO remove this once zigbuild uses Rust v1.87.0
             pub fn get(&self) -> &str {
                 self.0.as_str()
             }
 
+            #[cfg(not(target_os = "macos"))]
+            pub const fn get(&self) -> &str {
+                self.0.as_str()
+            }
+
             pub fn set(&mut self, value: String) {
                 self.0 = value;
             }
@@ -544,7 +560,7 @@ impl LogsTz {
 
 /// Store the logs alongside a HashSet, each log *should* generate a unique timestamp,
 /// so if we store the timestamp separately in a HashSet, we can then check if we should insert a log line into the
-/// stateful list dependent on whethere the timestamp is in the HashSet or not
+/// stateful list dependent on whether the timestamp is in the HashSet or not
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct Logs {
     logs: StatefulList<ListItem<'static>>,
@@ -570,10 +586,24 @@ impl Logs {
         }
     }
 
-    pub fn to_vec(&self) -> Vec<ListItem<'static>> {
-        self.logs.items.clone()
+    /// Get the logs vec, but instead of cloning to whole vec, only clone items with x of the currently selected index
+    /// Where x is the abs different of the index plus the panel height & a padding
+    /// The rest can be just empty list items
+    pub fn to_vec(&self, height: usize, padding: usize) -> Vec<ListItem<'static>> {
+        let current_index = self.logs.state.selected().unwrap_or_default();
+        self.logs
+            .items
+            .iter()
+            .enumerate()
+            .map(|(index, item)| {
+                if current_index.abs_diff(index) <= height + padding {
+                    item.clone()
+                } else {
+                    ListItem::from("")
+                }
+            })
+            .collect()
     }
-
     /// The rest of the methods are basically forwarding from the underlying StatefulList
     pub fn get_state_title(&self) -> String {
         self.logs.get_state_title()
@@ -594,10 +624,18 @@ impl Logs {
         self.logs.start();
     }
 
+    // TODO remove this once zigbuild uses Rust v1.87.0
+    #[cfg(target_os = "macos")]
+    #[allow(clippy::missing_const_for_fn)]
     pub fn len(&self) -> usize {
         self.logs.items.len()
     }
 
+    #[cfg(not(target_os = "macos"))]
+    pub const fn len(&self) -> usize {
+        self.logs.items.len()
+    }
+
     pub const fn state(&mut self) -> &mut ListState {
         &mut self.logs.state
     }
